@import "compass/reset";
@import "compass/typography/lists/inline-list";
@import "compass/utilities/general/float";

$layoutgala-container-selector: unquote("div.container");
$layoutgala-header-selector: h1;
$layoutgala-wrapper-selector: unquote("div.wrapper");
$layoutgala-content-selector: unquote("div.content");
$layoutgala-aside1-selector: unquote("div.navigation");
$layoutgala-aside2-selector: unquote("div.extra");
$layoutgala-footer-selector: unquote("div.footer");

#{$layoutgala-header-selector} {
	background: #EEE;
	color: #79B30B;
}
#{$layoutgala-aside1-selector} {
	background: #B9CAFF;
}
#{$layoutgala-content-selector} {
	background: white;
}
#{$layoutgala-aside2-selector}{
	background: #FF8539;
}
#{$layoutgala-footer-selector} {
	background: #333;
	color: #FFF;
}

div#intro,
div#details {
	text-align: justify;
	margin: 0 0 20px 20px;
}
a#indexIta {
	position: absolute;
	top: 31px;
	right: 10px;
}
a#htmllogo {
	position: absolute;
	top: 31px;
	right: 50px;
}
p.codice{
	text-align: left;
	background: #E8ECFF;
	line-height: 1.4;
}
ul#gallery {
	@include float(left);
	@include inline-list;
}
ul#gallery li{
	@include float(left);
	margin: 0 0 20px 20px;
	width: 120px;
	text-align: center;
	font-size: 50%;
}
ul#gallery div.container {
	display: block;
	width: 100px;
	height: 70px;
	border: 0px solid;
	margin: 0 auto 5px;
}
ul#gallery a {
	display: block;
	height: 140px;
	padding: 10px 0;
	background: #BFDDED;
	color: #333;
	border: 1px solid #007BC4;
	text-decoration: none;
}
ul#gallery a:hover {
	background: #007BC4;
	color: #FFF;
	border-color: #000;
}
div#details {
	clear: left;
}
