$layoutgala-container-selector: unquote("div.page") !default;
$layoutgala-wrapper-selector: unquote("div#pagebody") !default;
$layoutgala-content-selector: unquote("div#content") !default;
$layoutgala-aside1-selector: unquote("div.sidebar") !default;
$layoutgala-aside2-selector: unquote("div.farbar") !default;
$layoutgala-footer-selector: unquote("div.footer") !default;

@mixin layoutgala-negative-margin-left ($side, $width) {
	@if $side == left {
		margin-left: -100%;
	} @else {
		margin-left: -$width;
	}
}

@mixin layoutgala-nonzero ($rule, $width) {
	@if $width != 0 {
		#{$rule}: $width;
	}
}
