@import "compass/utilities/general/float";
@import "base";

@mixin layoutgala-liquid-center (
	$aside1-side: left,
	$aside1-width: 200px,
	$aside2-width: 200px,
	$margin-left: 0,
	$margin-center-left: 0,
	$margin-center-right: 0,
	$margin-right: 0,
	$content-padding-left: 0,
	$content-padding-right: $content-padding-left,
	$aside1-padding-left: $content-padding-left,
	$aside1-padding-right: $content-padding-left,
	$aside2-padding-left: $content-padding-left,
	$aside2-padding-right: $content-padding-left
) {
	$aside2-side: #{opposite-position($aside1-side)};
	#{$layoutgala-wrapper-selector} {
		@include float(left);
		width: 100%;
	}
	#{$layoutgala-content-selector} {
		margin-#{$aside1-side}: $aside1-width;
		margin-#{opposite-position($aside1-side)}: $aside2-width;
	}
	#{$layoutgala-aside1-selector} {
		@include float(left);
		width: $aside1-width;
		@include layoutgala-negative-margin-left ($aside1-side, $aside1-width);
	}
	#{$layoutgala-aside2-selector} {
		@include float(left);
		width: $aside2-width;
		@include layoutgala-negative-margin-left ($aside2-side, $aside2-width);
	}
	#{$layoutgala-footer-selector} {
		clear: left;
		width: 100%;
	}
}
