@import "compass/utilities/general/float";
@import "base";

@mixin layoutgala-fixed1 (
	$aside1-side: left,
	$container-width: 700px,
	$aside1-width: 350px
) {
	#{$layoutgala-container-selector} {
		width: $container-width;
		margin: 0 auto;
	}
	#{$layoutgala-aside1-selector} {
		@include float($aside1-side);
		width: $aside1-width;
	}
	#{$layoutgala-aside2-selector} {
		@include float(#{opposite-position($aside1-side)});
		width: ($container-width - $aside1-width);
	}
	#{$layoutgala-footer-selector} {
		clear: both;
		width: 100%;
	}
}
