@import "compass/utilities/general/float";
@import "base";

@mixin layoutgala-liquid-split (
	$aside1-side: left,
	$aside1-width: 50%
) {
	#{$layoutgala-aside1-selector} {
		@include float($aside1-side);
		width: $aside1-width;
	}
	#{$layoutgala-aside2-selector} {
		@include float($aside1-side);
		width: (100% - $aside1-width - 0.1%);
	}
	#{$layoutgala-footer-selector} {
		clear: $aside1-side;
		width: 100%;
	}
}
