// 40 CSS base layouts for same HTML markup using Compass
// Plugin by Jonas Smedegaard <http://dr.jones.dk/>
// Based on the work of Alessandro Fulciniti <http://blog.html.it/layoutgala/>

// Generate one (or more) of 40 CSS layouts for one generic HTML markup,
// without hacks nor workarounds and a good cross-browser compatibility.
// The layouts uses techniques like negative margins, any order columns
// and opposite floats.
// <http://www.alistapart.com/articles/negativemargins/>
// <http://www.positioniseverything.net/articles/onetruelayout/anyorder>

@import "layoutgala/base";
//TODO @import "layoutgala/liquid";
@import "layoutgala/liquid-center";
@import "layoutgala/liquid-left";
@import "layoutgala/liquid-right";
@import "layoutgala/liquid-right-alternative";
@import "layoutgala/liquid-split";
@import "layoutgala/percentage2-larger1";
@import "layoutgala/fixed2";
@import "layoutgala/fixed1";

@import "compass/utilities/general/float";

@mixin layoutgala-1 ($aside1-width, $aside2-width) {
	@include layoutgala-liquid-center(left, $aside1-width, $aside2-width);
}

@mixin layoutgala-2 ($aside1-width, $aside2-width) {
	@include layoutgala-liquid-center(right, $aside1-width, $aside2-width);
}

@mixin layoutgala-3 ($aside1-width, $aside2-width) {
	@include layoutgala-liquid-left(center, auto, $aside1-width, $aside2-width);
}

@mixin layoutgala-4 ($aside1-width, $aside2-width) {
	@include layoutgala-liquid-left(right, auto, $aside1-width, $aside2-width);
}

@mixin layoutgala-5 ($aside1-width, $aside2-width) {
	@include layoutgala-liquid-right(center, $aside1-width, $aside2-width);
}

@mixin layoutgala-6 ($aside1-width, $aside2-width) {
	@include layoutgala-liquid-right(left, $aside1-width, $aside2-width);
}

@mixin layoutgala-13 ($aside1-width, $aside2-width) {
	@include layoutgala-liquid-center(left, $aside1-width, $aside2-width);
}

@mixin layoutgala-14 ($aside1-width, $aside2-width) {
	@include layoutgala-liquid-center(right, $aside1-width, $aside2-width);
}

@mixin layoutgala-15 ($aside1-width, $aside2-width) {
	@include layoutgala-liquid-left(center, auto, $aside1-width, $aside2-width);
}

@mixin layoutgala-16 ($aside1-width, $aside2-width) {
	@include layoutgala-liquid-left(right, auto, $aside1-width, $aside2-width);
}

@mixin layoutgala-17 ($aside1-width, $aside2-width) {
	@include layoutgala-liquid-right-alternative(center, $aside1-width, $aside2-width);
}

@mixin layoutgala-18 ($aside1-width, $aside2-width) {
	@include layoutgala-liquid-right-alternative(left, $aside1-width, $aside2-width);
}

@mixin layoutgala-27 ($aside1-width) {
	@include layoutgala-liquid-split(left, $aside1-width);
}

@mixin layoutgala-28 ($aside1-width) {
	@include layoutgala-liquid-split(right, $aside1-width);
}

@mixin layoutgala-29 ($content-width, $margin: 0, $content-padding-left: 0, $content-padding-right: 0) {
	@include layoutgala-percentage2-larger1(right, $content-width, $margin, $content-padding-left, $content-padding-right);
}

@mixin layoutgala-30 ($content-width, $margin: 0, $content-padding-left: 0, $content-padding-right: 0) {
	@include layoutgala-percentage2-larger1(left, $content-width, $margin, $content-padding-left, $content-padding-right);
}

@mixin layoutgala-33 ($container-width, $content-width) {
	@include layoutgala-fixed2(left, $container-width, $content-width, aside1);
}

@mixin layoutgala-34 ($container-width, $content-width) {
	@include layoutgala-fixed2(right, $container-width, $content-width, aside1);
}

@mixin layoutgala-35 ($container-width, $content-width) {
	@include layoutgala-fixed2(right, $container-width, $content-width, content);
}

@mixin layoutgala-36 ($container-width, $content-width) {
	@include layoutgala-fixed2(left, $container-width, $content-width, content);
}

@mixin layoutgala-37 ($container-width, $content-width) {
	@include layoutgala-fixed2(right, $container-width, $content-width, container);
}

@mixin layoutgala-38 ($container-width, $content-width) {
	@include layoutgala-fixed2(right, $container-width, $content-width, container);
}

@mixin layoutgala-39 ($container-width, $aside1-width) {
	@include layoutgala-fixed1(left, $container-width, $aside1-width);
}

@mixin layoutgala-40 ($container-width, $aside1-width) {
	@include layoutgala-fixed1(right, $container-width, $aside1-width);
}
