@import "layoutgala";
@import "base";

li#lg01 { @include layoutgala-1(25%, 25%); }
li#lg02 { @include layoutgala-2(25%, 25%); }
li#lg03 { @include layoutgala-3(25%, 25%); }
li#lg04 { @include layoutgala-4(25%, 25%); }
li#lg05 { @include layoutgala-5(25%, 25%); }
li#lg06 { @include layoutgala-6(25%, 25%); }
li#lg07 { div { visibility: hidden } div.container { visibility: visible } }
li#lg08 { div { visibility: hidden } div.container { visibility: visible } }
li#lg09 { div { visibility: hidden } div.container { visibility: visible } }
li#lg10 { div { visibility: hidden } div.container { visibility: visible } }
li#lg11 { div { visibility: hidden } div.container { visibility: visible } }
li#lg12 { div { visibility: hidden } div.container { visibility: visible } }
li#lg13 { @include layoutgala-13(200px/7, 200px/7); }
li#lg14 { @include layoutgala-14(200px/7, 200px/7); }
li#lg15 { @include layoutgala-15(200px/7, 200px/7); }
li#lg16 { @include layoutgala-16(200px/7, 200px/7); }
li#lg17 { @include layoutgala-17(200px/7, 200px/7); }
li#lg18 { @include layoutgala-18(200px/7, 200px/7); }
li#lg19 { div { visibility: hidden } div.container { visibility: visible } }
li#lg20 { div { visibility: hidden } div.container { visibility: visible } }
li#lg21 { div { visibility: hidden } div.container { visibility: visible } }
li#lg22 { div { visibility: hidden } div.container { visibility: visible } }
li#lg23 { div { visibility: hidden } div.container { visibility: visible } }
li#lg24 { div { visibility: hidden } div.container { visibility: visible } }
li#lg25 { div { visibility: hidden } div.container { visibility: visible } }
li#lg26 { div { visibility: hidden } div.container { visibility: visible } }
li#lg27 { @include layoutgala-27(50%); }
li#lg28 { @include layoutgala-28(50%); }
li#lg29 { @include layoutgala-29(70%); }
li#lg30 { @include layoutgala-30(70%); }
li#lg31 { div { visibility: hidden } div.container { visibility: visible } }
li#lg32 { div { visibility: hidden } div.container { visibility: visible } }
li#lg33 { @include layoutgala-33(700px/7, 500px/7); }
li#lg34 { @include layoutgala-34(700px/7, 500px/7); }
li#lg35 { @include layoutgala-35(700px/7, 500px/7); }
li#lg36 { @include layoutgala-36(700px/7, 500px/7); }
li#lg37 { @include layoutgala-37(700px/7, 500px/7); }
li#lg38 { @include layoutgala-38(700px/7, 500px/7); }
li#lg39 { @include layoutgala-39(700px/7, 350px/7); }
li#lg40 { @include layoutgala-40(700px/7, 350px/7); }
