@import "compass/utilities/general/float";
@import "base";

// TODO: test if layoutgala-liquid-right can be reused instead
@mixin layoutgala-liquid-right-alternative (
	$aside1-side: left,
	$aside1-width: 200px,
	$aside2-width: 200px
) {
	#{$layoutgala-wrapper-selector} {
		@include float(right);
		width: 100%;
		margin-left: -($aside1-width + $aside2-width);
	}
	#{$layoutgala-content-selector} {
		margin-left: ($aside1-width + $aside2-width);
	}
	#{$layoutgala-aside1-selector} {
		@if $aside1-side == left {
			@include float(left);
		} @else {
			@include float(right);
		}
		width: $aside1-width;
	}
	#{$layoutgala-aside2-selector} {
		@include float(right);
		width: $aside2-width;
	}
	#{$layoutgala-footer-selector} {
		@if $aside1-side == center {
			clear: both;
		} @else {
			clear: right;
		}
		width: 100%;
	}
}
